{% extends "orga/base.html" %} {% load i18n %} {% load static %} {% block extra_title %}{% translate "Event History" %} :: {% endblock extra_title %} {% block stylesheets %} {% endblock stylesheets %} {% block scripts %}
{% endblock scripts %} {% block content %}

## {% translate "Event History" %}

{{ filter_form }}
{% include "common/logs.html" with entries=log_entries %} {% include "orga/includes/pagination.html" %}
{% endblock content %}